==> unit-1.0.49-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNewsTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNewsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public NewsTemplate.Header. _11_2_11658220501 _11_2_11658220501;
	public NewsTemplate.Header._11_2_11658220501. _12_3_01249224688 _12_3_01249224688;
	public NewsTemplate.Header._11_2_11658220501._12_3_01249224688. Label label;
	public NewsTemplate.Header._11_2_11658220501. Count count;
	public _16_1_0713941326 _16_1_0713941326;
	public NewsTemplate._16_1_0713941326. _17_2_01573017336 _17_2_01573017336;
	public NewsTemplate._16_1_0713941326._17_2_01573017336. NewsList newsList;

    public AbstractNewsTemplate(B box) {
        super(box);
        id("newsTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a488525792").owner(AbstractNewsTemplate.this));
		if (header != null) _11_2_11658220501 = header._11_2_11658220501;
		if (_11_2_11658220501 != null) _12_3_01249224688 = header._11_2_11658220501._12_3_01249224688;
		if (_12_3_01249224688 != null) label = header._11_2_11658220501._12_3_01249224688.label;
		if (_11_2_11658220501 != null) count = header._11_2_11658220501.count;
		if (_16_1_0713941326 == null) _16_1_0713941326 = register(new _16_1_0713941326(box()).<_16_1_0713941326>id("a_1090831066").owner(AbstractNewsTemplate.this));
		if (_16_1_0713941326 != null) _17_2_01573017336 = _16_1_0713941326._17_2_01573017336;
		if (_17_2_01573017336 != null) newsList = _16_1_0713941326._17_2_01573017336.newsList;
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NewsTemplate.Header. _11_2_11658220501 _11_2_11658220501;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_11_2_11658220501 == null) _11_2_11658220501 = register(new _11_2_11658220501(box()).<_11_2_11658220501>id("a1378858195").owner(AbstractNewsTemplate.this));
		}

		public class _11_2_11658220501 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public NewsTemplate.Header._11_2_11658220501. _12_3_01249224688 _12_3_01249224688;
			public NewsTemplate.Header._11_2_11658220501. Count count;

			public _11_2_11658220501(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_12_3_01249224688 == null) _12_3_01249224688 = register(new _12_3_01249224688(box()).<_12_3_01249224688>id("a1358273901").owner(AbstractNewsTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a_1100913553").owner(AbstractNewsTemplate.this));
			}

			public class _12_3_01249224688 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public NewsTemplate.Header._11_2_11658220501._12_3_01249224688. Label label;

				public _12_3_01249224688(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (label == null) label = register(new Label(box()).<Label>id("a_2012988266").owner(AbstractNewsTemplate.this));
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public Label(B box) {
						super(box);
						_value("News");
					}

					@Override
					public void init() {
						super.init();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}
			}
		}
	}

	public class _16_1_0713941326 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NewsTemplate._16_1_0713941326. _17_2_01573017336 _17_2_01573017336;

		public _16_1_0713941326(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_17_2_01573017336 == null) _17_2_01573017336 = register(new _17_2_01573017336(box()).<_17_2_01573017336>id("a1218645133").owner(AbstractNewsTemplate.this));
		}

		public class _17_2_01573017336 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public NewsTemplate._16_1_0713941326._17_2_01573017336. NewsList newsList;

			public _17_2_01573017336(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (newsList == null) newsList = register(new NewsList(box()).<NewsList>id("a1595842283").owner(AbstractNewsTemplate.this));
			}

			public class NewsList extends io.intino.alexandria.ui.displays.components.List<B, NewsListItem, org.monet.space.kernel.model.news.Post>  {

				public NewsList(B box) {
					super(box);

					_pageSize(20);
				}

				@Override
				public void init() {
					super.init();
				}

				public NewsListItem create(org.monet.space.kernel.model.news.Post element) {
					NewsListItem result = new NewsListItem((UnitBox)box());
					result.id(java.util.UUID.randomUUID().toString());
					result.item(element);
					return result;
				}
			}
		}
	}
}

==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractNewsTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractNewsTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Header header;
	public NewsTemplate.Header. _11_2_11658220501 _11_2_11658220501;
	public NewsTemplate.Header._11_2_11658220501. _12_3_01249224688 _12_3_01249224688;
	public NewsTemplate.Header._11_2_11658220501._12_3_01249224688. Label label;
	public NewsTemplate.Header._11_2_11658220501. Count count;
	public _16_1_0713941326 _16_1_0713941326;
	public NewsTemplate._16_1_0713941326. _17_2_01573017336 _17_2_01573017336;
	public NewsTemplate._16_1_0713941326._17_2_01573017336. NewsList newsList;

    public AbstractNewsTemplate(B box) {
        super(box);
        id("newsTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (header == null) header = register(new Header(box()).<Header>id("a488525792").owner(AbstractNewsTemplate.this));
		if (header != null) _11_2_11658220501 = header._11_2_11658220501;
		if (_11_2_11658220501 != null) _12_3_01249224688 = header._11_2_11658220501._12_3_01249224688;
		if (_12_3_01249224688 != null) label = header._11_2_11658220501._12_3_01249224688.label;
		if (_11_2_11658220501 != null) count = header._11_2_11658220501.count;
		if (_16_1_0713941326 == null) _16_1_0713941326 = register(new _16_1_0713941326(box()).<_16_1_0713941326>id("a_1090831066").owner(AbstractNewsTemplate.this));
		if (_16_1_0713941326 != null) _17_2_01573017336 = _16_1_0713941326._17_2_01573017336;
		if (_17_2_01573017336 != null) newsList = _16_1_0713941326._17_2_01573017336.newsList;
	}

    @Override
    public void remove() {
        super.remove();
	    if (header != null) header.unregister();
	    if (_16_1_0713941326 != null) _16_1_0713941326.unregister();
	}

	public class Header extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NewsTemplate.Header. _11_2_11658220501 _11_2_11658220501;

		public Header(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_11_2_11658220501 == null) _11_2_11658220501 = register(new _11_2_11658220501(box()).<_11_2_11658220501>id("a1378858195").owner(AbstractNewsTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_11_2_11658220501 != null) _11_2_11658220501.unregister();
		}

		public class _11_2_11658220501 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public NewsTemplate.Header._11_2_11658220501. _12_3_01249224688 _12_3_01249224688;
			public NewsTemplate.Header._11_2_11658220501. Count count;

			public _11_2_11658220501(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_12_3_01249224688 == null) _12_3_01249224688 = register(new _12_3_01249224688(box()).<_12_3_01249224688>id("a1358273901").owner(AbstractNewsTemplate.this));
				if (count == null) count = register(new Count(box()).<Count>id("a_1100913553").owner(AbstractNewsTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_12_3_01249224688 != null) _12_3_01249224688.unregister();
				if (count != null) count.unregister();
			}

			public class _12_3_01249224688 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public NewsTemplate.Header._11_2_11658220501._12_3_01249224688. Label label;

				public _12_3_01249224688(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (label == null) label = register(new Label(box()).<Label>id("a_2012988266").owner(AbstractNewsTemplate.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (label != null) label.unregister();
				}

				public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

					public Label(B box) {
						super(box);
						_value("News");
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}
			}

			public class Count extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public Count(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}
		}
	}

	public class _16_1_0713941326 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public NewsTemplate._16_1_0713941326. _17_2_01573017336 _17_2_01573017336;

		public _16_1_0713941326(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_17_2_01573017336 == null) _17_2_01573017336 = register(new _17_2_01573017336(box()).<_17_2_01573017336>id("a1218645133").owner(AbstractNewsTemplate.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_17_2_01573017336 != null) _17_2_01573017336.unregister();
		}

		public class _17_2_01573017336 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public NewsTemplate._16_1_0713941326._17_2_01573017336. NewsList newsList;

			public _17_2_01573017336(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (newsList == null) newsList = register(new NewsList(box()).<NewsList>id("a1595842283").owner(AbstractNewsTemplate.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (newsList != null) newsList.unregister();
			}

			public class NewsList extends io.intino.alexandria.ui.displays.components.List<B, NewsListItem, org.monet.space.kernel.model.news.Post>  {

				public NewsList(B box) {
					super(box);

					_pageSize(20);
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}

				public NewsListItem create(org.monet.space.kernel.model.news.Post element) {
					NewsListItem result = new NewsListItem((UnitBox)box());
					result.id(java.util.UUID.randomUUID().toString());
					result.item(element);
					return result;
				}
			}
		}
	}
}
